@@ -1,9 +1,9 @@
 package Data::Sah::Coerce::perl::To_str::From_str::normalize_perl_distname;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-07'; # DATE
+our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,10 +28,11 @@ sub coerce {
     $res->{expr_coerce} = join(
         "",
         "do { my \$tmp = $dt;",
-        "  my \$versuffix = ''; \$versuffix = \$1 if \$tmp =~ s/(\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*)\\z//;", # extract version suffix part first
+        "  my \$argssuffix = ''; \$argssuffix = \$1 if \$tmp =~ s/(=.*)\\z//;",                                    # extract args suffix (=arg1,arg2) first
+        "  my \$versuffix  = ''; \$versuffix  = \$1 if \$tmp =~ s/(\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*)\\z//;", # extract version suffix (@1.23) first
         "  \$tmp = \$1 if \$tmp =~ m!\\A(\\w+(?:/\\w+)*)\.pm\\z!;",
         "  \$tmp =~ s!::?|/|\\.!-!g;",
-        "  \$tmp . \$versuffix",
+        "  \$tmp . \$versuffix . \$argssuffix",
         "}",
     );
 
@@ -53,7 +54,7 @@ Data::Sah::Coerce::perl::To_str::From_str::normalize_perl_distname
 
 =head1 VERSION
 
-This document describes version 0.028 of Data::Sah::Coerce::perl::To_str::From_str::normalize_perl_distname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Data::Sah::Coerce::perl::To_str::From_str::normalize_perl_distname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 DESCRIPTION
 
