@@ -1,10 +1,12 @@
 package Sah::Schema::perl::distname;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
-    summary => 'Perl distribution name',
+    summary => 'Perl distribution name, e.g. Foo-Bar',
     match => '\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\z',
     'x.perl.coerce_rules' => [
         'From_str::normalize_perl_distname',
@@ -13,10 +15,22 @@ our $schema = [str => {
     # provide a default completion which is from list of installed perl distributions
     'x.completion' => 'perl_distname',
 
+    description => <<'_',
+
+For convenience (particularly in CLI with tab completion), you can input one of:
+
+    Foo::Bar
+    Foo/Bar
+    Foo/Bar.pm
+    Foo.Bar
+
+and it will be coerced into Foo-Bar form.
+
+_
 }, {}];
 
 1;
-# ABSTRACT: Perl distribution name
+# ABSTRACT: Perl distribution name, e.g. Foo-Bar
 
 __END__
 
@@ -26,11 +40,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::distname - Perl distribution name
+Sah::Schema::perl::distname - Perl distribution name, e.g. Foo-Bar
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::distname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::distname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -44,7 +58,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -64,6 +78,17 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
      ...
  }
 
+=head1 DESCRIPTION
+
+For convenience (particularly in CLI with tab completion), you can input one of:
+
+ Foo::Bar
+ Foo/Bar
+ Foo/Bar.pm
+ Foo.Bar
+
+and it will be coerced into Foo-Bar form.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Perl>.
