@@ -1,9 +1,9 @@
 package Sah::Schema::perl::distname_with_optional_ver;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-07'; # DATE
+our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl distribution name (e.g. Foo-Bar) with optional version number suffix (e.g. Foo-Bar@0.001)',
@@ -15,6 +15,19 @@ our $schema = [str => {
     # provide a default completion which is from list of installed perl distributions
     'x.completion' => 'perl_distname',
 
+    description => <<'_',
+
+For convenience (particularly in CLI with tab completion), you can input one of:
+
+    Foo::Bar
+    Foo/Bar
+    Foo/Bar.pm
+    Foo.Bar
+
+and it will be coerced into Foo-Bar form.
+
+_
+
     examples => [
         {value=>'', valid=>0},
         {value=>'Foo-Bar', valid=>1},
@@ -43,7 +56,7 @@ Sah::Schema::perl::distname_with_optional_ver - Perl distribution name (e.g. Foo
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::distname_with_optional_ver (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::distname_with_optional_ver (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -57,7 +70,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -79,21 +92,32 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- "Foo-Bar"  # valid
+ undef  # valid
 
- "Foo-Bar\@1"  # valid
+ undef  # valid
 
- "Foo-Bar\@1.0"  # valid
+ undef  # valid
 
- "Foo::Bar\@1.0.0"  # valid, becomes "Foo-Bar\@1.0.0"
+ undef  # valid
 
- "Foo-Bar\@0.5_001"  # valid
+ undef  # valid
 
- "Foo::Bar\@0.5_001"  # valid, becomes "Foo-Bar\@0.5_001"
+ undef  # valid
 
- "Foo-Bar\@a"  # INVALID
+ undef  # INVALID
+
+=head1 DESCRIPTION
+
+For convenience (particularly in CLI with tab completion), you can input one of:
+
+ Foo::Bar
+ Foo/Bar
+ Foo/Bar.pm
+ Foo.Bar
+
+and it will be coerced into Foo-Bar form.
 
 =head1 HOMEPAGE
 
