@@ -1,35 +1,16 @@
 package Sah::Schema::perl::modargs;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
-
-our $schema = [str => {
-    summary => 'Perl module name with optional arguments',
-    description => <<'_',
-
-Perl module name with optional arguments which will be used as import arguments,
-just like the `-MMODULE=ARGS` shortcut that `perl` provides. Examples:
-
-    Foo
-    Foo::Bar
-    Foo::Bar=arg1,arg2
-
-See also: `perl::modname`.
-
-_
-    match => '\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*(?:=.*)?\z',
-
-    #'x.perl.coerce_rules' => [
-    #    'From_str::normalize_perl_modname',
-    #],
-
-    # XXX also provide completion for arguments
-    'x.completion' => 'perl_modname',
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
+our $schema = ['perl::modname_with_optional_args' => {
+    summary => 'Shorter alias for perl::modname_with_optional_args',
 }, {}];
 
 1;
-# ABSTRACT: Perl module name with optional arguments
+# ABSTRACT: Shorter alias for perl::modname_with_optional_args
 
 __END__
 
@@ -39,11 +20,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::modargs - Perl module name with optional arguments
+Sah::Schema::perl::modargs - Shorter alias for perl::modname_with_optional_args
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::modargs (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::modargs (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -57,7 +38,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -77,17 +58,6 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
      ...
  }
 
-=head1 DESCRIPTION
-
-Perl module name with optional arguments which will be used as import arguments,
-just like the C<-MMODULE=ARGS> shortcut that C<perl> provides. Examples:
-
- Foo
- Foo::Bar
- Foo::Bar=arg1,arg2
-
-See also: C<perl::modname>.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Perl>.
