@@ -1,18 +1,16 @@
 package Sah::Schema::perl::modname;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
-    summary => 'Perl module name',
+    summary => 'Perl module name, e.g. Foo::Bar',
     description => <<'_',
 
-Perl module name, e.g. `Foo`, `Foo::Bar`.
-
-Contains coercion rule so you can also input `Foo-Bar`, `Foo/Bar`, or
-`Foo/Bar.pm` and it will be normalized into `Foo::Bar`.
-
-See also: `perl::modargs`.
+Contains coercion rule so you can also input `Foo-Bar`, `Foo/Bar`, `Foo/Bar.pm`
+or even 'Foo.Bar' and it will be normalized into `Foo::Bar`.
 
 _
     match => '\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*\z',
@@ -24,10 +22,20 @@ _
     # provide a default completion which is from list of installed perl modules
     'x.completion' => 'perl_modname',
 
+    examples => [
+        {value=>'', valid=>0},
+        {value=>'Foo::Bar', valid=>1},
+        {value=>'Foo-Bar', valid=>1, validated_value=>'Foo::Bar'},
+        {value=>'Foo/Bar', valid=>1, validated_value=>'Foo::Bar'},
+        {value=>'Foo/Bar.pm', valid=>1, validated_value=>'Foo::Bar'},
+        {value=>'Foo.Bar', valid=>1, validated_value=>'Foo::Bar'},
+        {value=>'Foo|Bar', valid=>0},
+    ],
+
 }, {}];
 
 1;
-# ABSTRACT: Perl module name
+# ABSTRACT: Perl module name, e.g. Foo::Bar
 
 __END__
 
@@ -37,11 +45,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::modname - Perl module name
+Sah::Schema::perl::modname - Perl module name, e.g. Foo::Bar
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -55,7 +63,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -75,14 +83,26 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
      ...
  }
 
+Sample data:
+
+ undef  # INVALID
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # INVALID
+
 =head1 DESCRIPTION
 
-Perl module name, e.g. C<Foo>, C<Foo::Bar>.
-
-Contains coercion rule so you can also input C<Foo-Bar>, C<Foo/Bar>, or
-C<Foo/Bar.pm> and it will be normalized into C<Foo::Bar>.
-
-See also: C<perl::modargs>.
+Contains coercion rule so you can also input C<Foo-Bar>, C<Foo/Bar>, C<Foo/Bar.pm>
+or even 'Foo.Bar' and it will be normalized into C<Foo::Bar>.
 
 =head1 HOMEPAGE
 
