@@ -1,14 +1,14 @@
 package Sah::Schema::perl::modname_or_prefix;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
-    summary => 'Perl module name or prefix',
+    summary => 'Perl module name (e.g. Foo::Bar) or prefix (e.g. Foo::Bar::)',
     description => <<'_',
 
-Perl module name e.g. `Foo::Bar` or prefix e.g. `Foo::Bar::`.
-
 Contains coercion rule so inputing `Foo-Bar` or `Foo/Bar` will be normalized to
 `Foo::Bar` while inputing `Foo-Bar-` or `Foo/Bar/` will be normalized to
 `Foo::Bar::`
@@ -25,10 +25,21 @@ _
     # provide a default completion which is from list of installed perl modules
     'x.completion' => 'perl_modname_or_prefix',
 
+    examples => [
+        {value=>'', valid=>0},
+        {value=>'Foo::Bar', valid=>1},
+        {value=>'Foo::Bar::', valid=>1},
+        {value=>'Foo/Bar', valid=>1, validated_value=>'Foo::Bar'},
+        {value=>'Foo/Bar/', valid=>1, validated_value=>'Foo::Bar::'},
+        {value=>'Foo-Bar', valid=>1, validated_value=>'Foo::Bar'},
+        {value=>'Foo-Bar-', valid=>1, validated_value=>'Foo::Bar::'},
+        {value=>'Foo|Bar', valid=>0},
+    ],
+
 }, {}];
 
 1;
-# ABSTRACT: Perl module name or prefix
+# ABSTRACT: Perl module name (e.g. Foo::Bar) or prefix (e.g. Foo::Bar::)
 
 __END__
 
@@ -38,11 +49,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::modname_or_prefix - Perl module name or prefix
+Sah::Schema::perl::modname_or_prefix - Perl module name (e.g. Foo::Bar) or prefix (e.g. Foo::Bar::)
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::modname_or_prefix (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::modname_or_prefix (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -56,7 +67,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -76,9 +87,25 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
      ...
  }
 
-=head1 DESCRIPTION
+Sample data:
 
-Perl module name e.g. C<Foo::Bar> or prefix e.g. C<Foo::Bar::>.
+ undef  # INVALID
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # INVALID
+
+=head1 DESCRIPTION
 
 Contains coercion rule so inputing C<Foo-Bar> or C<Foo/Bar> will be normalized to
 C<Foo::Bar> while inputing C<Foo-Bar-> or C<Foo/Bar/> will be normalized to
