@@ -1,12 +1,12 @@
 package Sah::Schema::perl::modname_with_ver;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-07'; # DATE
+our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
-    summary => 'Perl module name with version number suffix (e.g. Foo::Bar@0.001)',
+    summary => 'Perl module name with version number suffix, e.g. Foo::Bar@0.001',
     match => '\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\z',
     'x.perl.coerce_rules' => [
         'From_str::normalize_perl_modname',
@@ -29,7 +29,7 @@ our $schema = [str => {
 }, {}];
 
 1;
-# ABSTRACT: Perl module name with version number suffix (e.g. Foo::Bar@0.001)
+# ABSTRACT: Perl module name with version number suffix, e.g. Foo::Bar@0.001
 
 __END__
 
@@ -39,11 +39,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::modname_with_ver - Perl module name with version number suffix (e.g. Foo::Bar@0.001)
+Sah::Schema::perl::modname_with_ver - Perl module name with version number suffix, e.g. Foo::Bar@0.001
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::modname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::modname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -79,21 +79,21 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- ""  # INVALID
+ undef  # INVALID
 
- "Foo-Bar"  # INVALID
+ undef  # INVALID
 
- "Foo::Bar"  # INVALID
+ undef  # INVALID
 
- "Foo-Bar\@1.0.0"  # valid, becomes "Foo::Bar\@1.0.0"
+ undef  # valid
 
- "Foo::Bar\@1.0.0"  # valid
+ undef  # valid
 
- "Foo-Bar\@0.5_001"  # valid, becomes "Foo::Bar\@0.5_001"
+ undef  # valid
 
- "Foo::Bar\@0.5_001"  # valid
+ undef  # valid
 
- "Foo::Bar\@a"  # INVALID
+ undef  # INVALID
 
 =head1 HOMEPAGE
 
