@@ -1,10 +1,12 @@
 package Sah::Schema::perl::modnames;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [array => {
-    summary => 'Perl module names',
+    summary => 'Array of Perl module names, e.g. ["Foo::Bar", "Baz"]',
     description => <<'_',
 
 Array of Perl module names, where each element is of `perl::modname` schema,
@@ -34,7 +36,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Perl module names
+# ABSTRACT: Array of Perl module names, e.g. ["Foo::Bar", "Baz"]
 
 __END__
 
@@ -44,11 +46,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::modnames - Perl module names
+Sah::Schema::perl::modnames - Array of Perl module names, e.g. ["Foo::Bar", "Baz"]
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::modnames (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::modnames (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -62,7 +64,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
