@@ -1,10 +1,12 @@
 package Sah::Schema::perl::modprefix;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
-    summary => 'Perl module prefix',
+    summary => 'Perl module prefix, e.g. Foo::Bar::',
     description => <<'_',
 
 Perl module prefix, e.g. `Foo::Bar::`. An empty prefix ('') is also allowed.
@@ -20,8 +22,6 @@ Contains coercion rule so you can also input:
 
 and it will be normalized into `Foo::Bar::`.
 
-See also: `perl::modprefix`.
-
 _
     match => '\A(?:[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*::)?\z',
 
@@ -32,10 +32,22 @@ _
     # provide a default completion which is from list of installed perl prefixes
     'x.completion' => 'perl_modprefix',
 
+    examples => [
+        {value=>'', valid=>1},
+        {value=>'::', valid=>0},
+        {value=>'Foo::', valid=>1},
+        {value=>'Foo::Bar', valid=>1, validated_value=>'Foo::Bar::'},
+        {value=>'Foo::Bar::', valid=>1},
+        {value=>'::Foo', valid=>0},
+        {value=>'Foo', valid=>1, validated_value=>'Foo::'},
+        {value=>'Foo/', valid=>1, validated_value=>'Foo::'},
+        {value=>'Foo-', valid=>1, validated_value=>'Foo::'},
+    ],
+
 }, {}];
 
 1;
-# ABSTRACT: Perl module prefix
+# ABSTRACT: Perl module prefix, e.g. Foo::Bar::
 
 __END__
 
@@ -45,11 +57,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::modprefix - Perl module prefix
+Sah::Schema::perl::modprefix - Perl module prefix, e.g. Foo::Bar::
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -63,7 +75,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -83,6 +95,26 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
      ...
  }
 
+Sample data:
+
+ undef  # valid
+
+ undef  # INVALID
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # INVALID
+
+ undef  # valid
+
+ undef  # valid
+
+ undef  # valid
+
 =head1 DESCRIPTION
 
 Perl module prefix, e.g. C<Foo::Bar::>. An empty prefix ('') is also allowed.
@@ -98,8 +130,6 @@ Contains coercion rule so you can also input:
 
 and it will be normalized into C<Foo::Bar::>.
 
-See also: C<perl::modprefix>.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Perl>.
