@@ -1,10 +1,12 @@
 package Sah::Schema::perl::modprefixes;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [array => {
-    summary => 'Perl module prefixes',
+    summary => 'Perl module prefixes, e.g. ["", "Foo::", "Foo::Bar::"]',
     description => <<'_',
 
 Array of Perl module prefixes, where each element is of `perl::modprefix`
@@ -35,7 +37,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Perl module prefixes
+# ABSTRACT: Perl module prefixes, e.g. ["", "Foo::", "Foo::Bar::"]
 
 __END__
 
@@ -45,11 +47,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::modprefixes - Perl module prefixes
+Sah::Schema::perl::modprefixes - Perl module prefixes, e.g. ["", "Foo::", "Foo::Bar::"]
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::modprefixes (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::modprefixes (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -63,7 +65,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
