@@ -1,12 +1,18 @@
 package Sah::Schema::perl::pm_filename;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
-    summary => 'Filename (.pm file)',
+    summary => 'Filename of perl module, e.g. /path/Foo.pm',
     description => <<'_',
 
+Use this schema if you want to accept a filesystem path containing Perl module.
+The value of this schema is in the convenience of CLI completion, as well as
+coercion from module name.
+
 String containing filename of a Perl module. For convenience, when value is in
 the form of:
 
@@ -54,7 +60,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Filename (.pm file)
+# ABSTRACT: Filename of perl module, e.g. /path/Foo.pm
 
 __END__
 
@@ -64,11 +70,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::pm_filename - Filename (.pm file)
+Sah::Schema::perl::pm_filename - Filename of perl module, e.g. /path/Foo.pm
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::pm_filename (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::pm_filename (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -82,7 +88,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -104,6 +110,10 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
 =head1 DESCRIPTION
 
+Use this schema if you want to accept a filesystem path containing Perl module.
+The value of this schema is in the convenience of CLI completion, as well as
+coercion from module name.
+
 String containing filename of a Perl module. For convenience, when value is in
 the form of:
 
@@ -142,6 +152,14 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Sah::Schema::perl::filename>
+
+L<Sah::Schema::perl::pod_or_pm_filename>
+
+L<Sah::Schema::perl::pod_filename>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
