@@ -1,10 +1,12 @@
 package Sah::Schema::perl::pod_or_pm_filename;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
-    summary => 'Filename (.pod or .pm file)',
+    summary => 'A .pod or .pm filename, e.g. /path/Foo.pm or /path/Bar/Baz.pod',
     description => <<'_',
 
 String containing filename of a Perl POD or module. For convenience, when value
@@ -60,7 +62,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Filename (.pod or .pm file)
+# ABSTRACT: A .pod or .pm filename, e.g. /path/Foo.pm or /path/Bar/Baz.pod
 
 __END__
 
@@ -70,11 +72,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::pod_or_pm_filename - Filename (.pod or .pm file)
+Sah::Schema::perl::pod_or_pm_filename - A .pod or .pm filename, e.g. /path/Foo.pm or /path/Bar/Baz.pod
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::pod_or_pm_filename (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::pod_or_pm_filename (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -88,7 +90,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -155,6 +157,14 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Sah::Schema::perl::filename>
+
+L<Sah::Schema::perl::pod_filename>
+
+L<Sah::Schema::perl::pm_filename>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
