@@ -1,10 +1,12 @@
 package Sah::Schema::perl::podname;
 
-our $DATE = '2020-05-07'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-05-08'; # DATE
+our $DIST = 'Sah-Schemas-Perl'; # DIST
+our $VERSION = '0.029'; # VERSION
 
 our $schema = ['str' => {
-    summary => 'Perl POD name',
+    summary => 'Perl POD name, e.g. Moose::Cookbook',
     description => <<'_',
 
 Perl POD name, e.g. `Config`, `Some::Other::POD`.
@@ -24,7 +26,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Perl POD name
+# ABSTRACT: Perl POD name, e.g. Moose::Cookbook
 
 __END__
 
@@ -34,11 +36,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::podname - Perl POD name
+Sah::Schema::perl::podname - Perl POD name, e.g. Moose::Cookbook
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::podname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::podname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -52,7 +54,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
