@@ -1,12 +1,12 @@
 package Sah::Schema::perl::unqualified_funcname;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-07'; # DATE
+our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 our $schema = [str => {
-    summary => 'Perl function name, must not be qualified with a package name',
+    summary => 'Perl function name which must not be qualified with a package name, e.g. subname',
     description => <<'_',
 
 Currently function name is restricted to this regex:
@@ -28,7 +28,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Perl function name, must not be qualified with a package name
+# ABSTRACT: Perl function name which must not be qualified with a package name, e.g. subname
 
 __END__
 
@@ -38,11 +38,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::unqualified_funcname - Perl function name, must not be qualified with a package name
+Sah::Schema::perl::unqualified_funcname - Perl function name which must not be qualified with a package name, e.g. subname
 
 =head1 VERSION
 
-This document describes version 0.028 of Sah::Schema::perl::unqualified_funcname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-07.
+This document describes version 0.029 of Sah::Schema::perl::unqualified_funcname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -56,7 +56,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
